@@ -3,7 +3,7 @@
  *  Jpeg Read Write Functions
  *
  * 
- *  $Header: /home/repository/rimage/src/Attic/jpegio.c,v 1.1.2.3 2003/10/17 06:00:06 tomo Exp $
+ *  $Header: /database/repository/rimage/src/Attic/jpegio.c,v 1.1.2.4 2004/03/19 06:11:11 tomo Exp $
  *  Copyright (c) 2003 Nikon Digital Technologies Co., Ltd.
  *  complete license terms see file LICENSE
  * 
@@ -11,7 +11,7 @@
 
 
 #include <stdio.h>
-#include "jpeglib.h"
+#include <jpeglib.h>
 #include <setjmp.h>
 
 struct my_error_mgr {
@@ -78,7 +78,7 @@ void read_JPEG_file (char **filename, double *image, int *ret)
 	int plane_size;
 	int i, j;
 	int line;
-	char *p;
+	//char *p;
 	
 	if ((infile = fopen(fname, "rb")) == NULL) {
 		*ret = -1;   /* couldn't open file */
@@ -105,12 +105,12 @@ void read_JPEG_file (char **filename, double *image, int *ret)
 	while (cinfo.output_scanline < cinfo.output_height) {
 		line = cinfo.output_scanline;  /* preserve current scanline */
 		(void) jpeg_read_scanlines(&cinfo, buffer, 1);
-		p = buffer[0]; 
+		unsigned char *p = buffer[0]; 
 		plane_size = cinfo.output_width * cinfo.output_height;
 		for (i = 0; i < cinfo.output_width; i++) {
 			for (j = 0; j<cinfo.output_components; j++) {
 				image[line + cinfo.output_height * i 
-					 + j * plane_size] = (unsigned char) *p++;
+					 + j * plane_size] = *p++;
 			}
 		}
 	}
